@@ -392,9 +392,6 @@ extern "C"
    EAPI Imlib_Updates imlib_image_draw_pixel(int x, int y, char make_updates);
    EAPI Imlib_Updates imlib_image_draw_line(int x1, int y1, int x2, int y2,
                                             char make_updates);
-   EAPI int imlib_clip_line(int x0, int y0, int x1, int y1, int xmin, int xmax,
-                            int ymin, int ymax, int *clip_x0, int *clip_y0,
-                            int *clip_x1, int *clip_y1);
    EAPI void imlib_image_draw_rectangle(int x, int y, int width, int height);
    EAPI void imlib_image_fill_rectangle(int x, int y, int width, int height);
    EAPI void imlib_image_copy_alpha_to_image(Imlib_Image image_source, int x,
